@@ -3,19 +3,19 @@
  * Copyright (C) 2003  Peter Hanappe and others.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License
- * as published by the Free Software Foundation; either version 2 of
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *  
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307, USA
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 #ifndef _FLUIDSYNTH_LOG_H
@@ -58,7 +58,7 @@ enum fluid_log_level {
   FLUID_WARN,    /**< Warning */
   FLUID_INFO,    /**< Verbose informational messages */
   FLUID_DBG,     /**< Debugging messages */
-  LAST_LOG_LEVEL
+  LAST_LOG_LEVEL /**< @deprecated As of 1.1.7 this enum value is deprecated and will be removed in a future release, because it prevents adding new enum values without breaking ABI compatibility. */
 };
 
 /**
@@ -67,12 +67,12 @@ enum fluid_log_level {
  * @param message Log message text
  * @param data User data pointer supplied to fluid_set_log_function().
  */
-typedef void (*fluid_log_function_t)(int level, const char* message, void* data);
+typedef void (*fluid_log_function_t)(int level, char* message, void* data);
 
 FLUIDSYNTH_API 
 fluid_log_function_t fluid_set_log_function(int level, fluid_log_function_t fun, void* data);
 
-FLUIDSYNTH_API void fluid_default_log_function(int level, const char* message, void* data);
+FLUIDSYNTH_API void fluid_default_log_function(int level, char* message, void* data);
 
 FLUIDSYNTH_API int fluid_log(int level, const char *fmt, ...);
 
