@@ -3,19 +3,19 @@
  * Copyright (C) 2003  Peter Hanappe and others.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License
- * as published by the Free Software Foundation; either version 2 of
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307, USA
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 #if HAVE_CONFIG_H
@@ -30,7 +30,11 @@
 
 #if !defined(WIN32) && !defined(MACINTOSH)
 #define _GNU_SOURCE
+#endif
+
+#if defined(HAVE_GETOPT_H)
 #include <getopt.h>
+#define GETOPT_SUPPORT 1
 #endif
 
 #include "fluidsynth.h"
@@ -53,7 +57,9 @@ void print_usage(void);
 void print_help(fluid_settings_t *settings);
 void print_welcome(void);
 
+#if !defined(MACINTOSH)
 static fluid_cmd_handler_t* newclient(void* data, char* addr);
+#endif
 
 /*
  * the globals
@@ -61,16 +67,6 @@ static fluid_cmd_handler_t* newclient(void* data, char* addr);
 fluid_cmd_handler_t* cmd_handler = NULL;
 int option_help = 0;		/* set to 1 if "-o help" is specified */
 
-/*
- * support for the getopt function
- */
-#if !defined(WIN32) && !defined(MACINTOSH)
-#define GETOPT_SUPPORT 1
-int getopt(int argc, char * const argv[], const char *optstring);
-extern char *optarg;
-extern int optind, opterr, optopt;
-#endif
-
 
 /* Process a command line option -o setting=value, for example: -o synth.polyhony=16 */
 void process_o_cmd_line_option(fluid_settings_t* settings, char* optarg)
@@ -93,6 +89,11 @@ void process_o_cmd_line_option(fluid_settings_t* settings, char* optarg)
     return;
   }
 
+  if (strcmp (optarg, "") == 0) {
+    fprintf (stderr, "Invalid -o option (name part is empty)\n");
+    return;
+  }
+
   switch(fluid_settings_get_type(settings, optarg)){
   case FLUID_NUM_TYPE:
     if (!fluid_settings_setnum (settings, optarg, atof (val)))
@@ -282,14 +283,18 @@ int main(int argc, char** argv)
   fluid_midi_driver_t* mdriver = NULL;
   fluid_audio_driver_t* adriver = NULL;
   fluid_synth_t* synth = NULL;
+#if !defined(MACINTOSH)
   fluid_server_t* server = NULL;
+#endif
   char* config_file = NULL;
   int audio_groups = 0;
   int audio_channels = 0;
   int with_server = 0;
   int dump = 0;
   int fast_render = 0;
+#ifdef LASH_ENABLED
   int connect_lash = 1;
+#endif
   char *optchars = "a:C:c:dE:f:F:G:g:hijK:L:lm:nO:o:p:R:r:sT:Vvz:";
 #ifdef LASH_ENABLED
   int enabled_lash = 0;		/* set to TRUE if lash gets enabled */
@@ -455,7 +460,9 @@ int main(int argc, char** argv)
       fluid_settings_setint(settings, "synth.audio-channels", audio_channels);
       break;
     case 'l':			/* disable LASH */
+#ifdef LASH_ENABLED
       connect_lash = 0;
+#endif
       break;
     case 'm':
       if (FLUID_STRCMP (optarg, "help") == 0)
@@ -576,15 +583,28 @@ int main(int argc, char** argv)
     }
 #endif
 
-  /* The 'groups' setting is only relevant for LADSPA operation
+  /* The 'groups' setting is relevant for LADSPA operation and channel mapping
+   * in rvoice_mixer.
    * If not given, set number groups to number of audio channels, because
    * they are the same (there is nothing between synth output and 'sound card')
    */
   if ((audio_groups == 0) && (audio_channels != 0)) {
       audio_groups = audio_channels;
   }
-  fluid_settings_setint(settings, "synth.audio-groups", audio_groups);
+  if (audio_groups != 0)
+  {
+      fluid_settings_setint(settings, "synth.audio-groups", audio_groups);
+  }
 
+  if (fast_render) {
+    midi_in = 0;
+    interactive = 0;
+    with_server = 0;
+    fluid_settings_setstr(settings, "player.timing-source", "sample");
+    fluid_settings_setint(settings, "synth.lock-memory", 0);
+    fluid_settings_setint(settings, "synth.parallel-render", 1); /* TODO: Fast_render should not need this, but currently do */
+  }
+  
   /* create the synthesizer */
   synth = new_fluid_synth(settings);
   if (synth == NULL) {
@@ -614,13 +634,6 @@ int main(int argc, char** argv)
 /*   signal(SIGINT, handle_signal); */
 #endif
 
-  if (fast_render) {
-    midi_in = 0;
-    interactive = 0;
-    with_server = 0;
-    fluid_settings_setstr(settings, "player.timing-source", "sample");    
-  }
-
   /* start the synthesis thread */
   if (!fast_render) {
     adriver = new_fluid_audio_driver(settings, synth);
@@ -693,6 +706,16 @@ int main(int argc, char** argv)
   }
 
   if (player != NULL) {
+
+    if (fluid_synth_get_sfont(synth, 0) == NULL) {
+      /* Try to load the default soundfont if no soundfont specified */
+      char *s;
+      if (fluid_settings_getstr(settings, "synth.default-soundfont", &s) <= 0)
+        s = NULL;
+      if ((s != NULL) && (s[0] != '\0'))
+        fluid_synth_sfload(synth, s, 1);
+    }
+
     fluid_player_play(player);
   }
 
@@ -729,6 +752,10 @@ int main(int argc, char** argv)
 
   if (fast_render) {
     char *filename;
+    if (player == NULL) {
+      fprintf(stderr, "No midi file specified!\n");
+      goto cleanup;
+    } 
 
     fluid_settings_dupstr (settings, "audio.file.name", &filename);
     printf ("Rendering audio to file '%s'..\n", filename);
@@ -739,7 +766,7 @@ int main(int argc, char** argv)
 
  cleanup:
 
-#if !defined(MACINTOSH) && !defined(WIN32)
+#if !defined(MACINTOSH)
   if (server != NULL) {
     /* if the user typed 'quit' in the shell, kill the server */
     if (!interactive) {
@@ -793,12 +820,13 @@ int main(int argc, char** argv)
   return 0;
 }
 
+#if !defined(MACINTOSH)
 static fluid_cmd_handler_t* newclient(void* data, char* addr)
 {
   fluid_synth_t* synth = (fluid_synth_t*) data;
   return new_fluid_cmd_handler(synth);
 }
-
+#endif
 
 /*
  * print_usage
@@ -815,7 +843,7 @@ void
 print_welcome()
 {
   printf("FluidSynth version %s\n"
-	 "Copyright (C) 2000-2009 Peter Hanappe and others.\n"
+	 "Copyright (C) 2000-2018 Peter Hanappe and others.\n"
 	 "Distributed under the LGPL license.\n"
 	 "SoundFont(R) is a registered trademark of E-mu Systems, Inc.\n\n",
 	 FLUIDSYNTH_VERSION);
